aboutsummaryrefslogtreecommitdiff
path: root/api/routes/receiveZBlock/index.js
diff options
context:
space:
mode:
Diffstat (limited to 'api/routes/receiveZBlock/index.js')
-rw-r--r--api/routes/receiveZBlock/index.js6
1 files changed, 3 insertions, 3 deletions
diff --git a/api/routes/receiveZBlock/index.js b/api/routes/receiveZBlock/index.js
index 3ad6100..4f1ae3d 100644
--- a/api/routes/receiveZBlock/index.js
+++ b/api/routes/receiveZBlock/index.js
@@ -7,7 +7,7 @@
* 3. Matches regular expression /Qm[A-Za-z0-9]{44}/
*
* Returns:
* - errno on failure
* - on success the string is processed for further
* validation to the function getvalidity()
*
@@ -20,9 +20,9 @@ module.exports = (req, res) => {
if (regex.test(req.body.zblock)){
getvalidity(req.body.zblock,res);
} else {
- res.send({errno:"Invalid data"});
+ res.send({error:"Invalid data"});
}
} else {
- res.send({errno:"Invalid data"});
+ res.send({error:"Invalid data"});
}
}
@@ -7,7 +7,7 @@
*
* Returns:
- * - errno on failure
+ * - error on failure
* - on success the string is processed for further
* validation to the function getvalidity()